Coverage for src/scicom/run.py: 0%

1 import argparse

2

3 parser = argparse.ArgumentParser(

4 prog='Run SciCom Simulations',

5 description='This script starts the server interfaces for the different ABM.',

6 epilog='During the running of this script, the interfaces should be reachable at http://127.0.0.1:8521'

7)

8

9 parser.add_argument(

10 'simulation',

11 choices=[

12 "randomletters", "historicalletters", "knowledgespread"

13 ]

14)

15

16

17 args = parser.parse_args()

18

19 if args.simulation == "randomletters":

20 from randomletters.server import server

21 server.launch()

22 elif args.simulation == "historicalletters":

23 from historicalletters.server import server

24 server.launch()

25 elif args.simulation == "knowledgespread":

26 from knowledgespread.server import server

27 server.launch()